%define major   0.9.8
%define libname %mklibname %{name} %{major}
%define devname %mklibname %{name} -d

Name:       podofo
Version:    0.9.8
Release:    %mkrel 2
Summary:    Tools and libraries to work with the PDF file format
Group:      Publishing
License:    GPL and LGPL
URL:        https://podofo.sourceforge.net/
Source0:    https://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.gz
Patch0:     podofo-0.9.3-fix-test-type.patch
Patch1:     podofo-0.9.4-freetype.patch

# Downstream patch for CVE-2019-20093
# https://sourceforge.net/p/podofo/tickets/75/
Patch20:        podofo_CVE-2019-20093.patch
# https://sourceforge.net/p/podofo/tickets/101/
Patch22:        podofo_maxbytes.patch
# Comment out some asserts in the testsuite which fail to build with gcc12
Patch23:	podofo-gcc12.patch

BuildRequires:  cmake
BuildRequires:  lua-devel
BuildRequires:  pkgconfig(cppunit)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(libcrypto)
BuildRequires:  pkgconfig(libidn)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(zlib)

%description
PoDoFo is a library to work with the PDF file format. The name comes from
the first letter of PDF (Portable Document Format). A few tools to work
with PDF files are already included in the PoDoFo package.

The PoDoFo library is a free, portable C++ library which includes classes
to parse PDF files and modify their contents into memory. The changes can be
written back to disk easily. The parser can also be used to extract
information from a PDF file (for example the parser could be used in a PDF
viewer). Besides parsing PoDoFo includes also very simple classes to create
your own PDF files. All classes are documented so it is easy to start writing
your own application using PoDoFo.


%package -n %{libname}
Summary:    Runtime library for %{name}
Group:      System/Libraries
License:    LGPLv2+

%description -n %{libname}
Runtime library for %{name}.


%package -n %{devname}
Summary:    Development files for %{name} library
Group:      Development/C
License:    LGPLv2+
Requires:   %{libname} = %{version}-%{release}
Provides:   %{name}-devel = %{version}-%{release}

%description -n %{devname}
Development files and documentation for the %{name} library.


%prep
%setup -q
%autopatch -p1

# fix pkgconfig file version
sed -i 's|@PODOFO_VERSION@|@PODOFO_SOVERSION@|' src/podofo/libpodofo.pc.in

%build
mkdir -p "test/TokenizerTest/objects"

%cmake -DPODOFO_BUILD_SHARED=1
%cmake_build

%install
%cmake_install

%files
%doc COPYING
%{_bindir}/%{name}*

%files -n %{libname}
%doc AUTHORS COPYING.LIB ChangeLog FAQ.html README.html TODO
%{_libdir}/lib%{name}.so.%{major}

%files -n %{devname}
%doc doc/html
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/lib%{name}.pc
%{_mandir}/man1/%{name}*.1*


%changelog
* Mon Dec 12 2022 ns80 <ns80> 0.9.8-2.mga9
+ Revision: 1921133
- rebuild for new libtiff

* Mon Sep 19 2022 luigiwalser <luigiwalser> 0.9.8-1.mga9
+ Revision: 1890678
- 0.9.8
- update patch 1 from fedora
- remove upstreamed patch 21
- library major is now 0.9.8
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Sat Oct 02 2021 wally <wally> 0.9.7-2.mga9
+ Revision: 1747735
- rebuild for openssl 3.0.0

* Fri Aug 06 2021 luigiwalser <luigiwalser> 0.9.7-1.mga9
+ Revision: 1739844
- 0.9.7
- remove upstreamed patches
- update rediffed patches from fedora

* Sat Apr 03 2021 wally <wally> 0.9.6-5.mga9
+ Revision: 1712955
- rebuild for lua 5.4

* Fri Jul 17 2020 ns80 <ns80> 0.9.6-4.mga8
+ Revision: 1606686
- add fedora patches for several security issues (mga#24385)

* Sat May 09 2020 daviddavid <daviddavid> 0.9.6-3.mga8
+ Revision: 1581936
- add upstream patch to fix pkgconfig file name
  * pkgconfig(libpodofo) instead of pkgconfig(libpodofo-0)

* Fri Feb 14 2020 umeabot <umeabot> 0.9.6-2.mga8
+ Revision: 1522152
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Mon Jan 21 2019 luigiwalser <luigiwalser> 0.9.6-1.mga7
+ Revision: 1358766
- 0.9.6 (final)
- add patches from upstream via fedora to fix more security issues

* Fri Nov 02 2018 kekepower <kekepower> 0.9.6-0.r1947.1.mga7
+ Revision: 1327669
- Update to latest revision, svn r1947
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild

* Fri May 11 2018 kekepower <kekepower> 0.9.6-0.r1855.3.mga7
+ Revision: 1228378
- Rebuild for libidn 1.35

* Sat Sep 09 2017 cjw <cjw> 0.9.6-0.r1855.2.mga7
+ Revision: 1152040
- rebuild for openssl 1.1
- revert BR pkgconfig(lua) back to lua5.2-devel

* Sat Jul 01 2017 akien <akien> 0.9.6-0.r1855.1.mga6
+ Revision: 1108854
- SVN snapshot r1855, pre 0.9.6 with many security fixes (mga#20234)
- Add libidn and libpng BRs

* Fri Aug 12 2016 luigiwalser <luigiwalser> 0.9.4-1.mga6
+ Revision: 1046114
- 0.9.4

* Fri Feb 12 2016 umeabot <umeabot> 0.9.3-7.mga6
+ Revision: 958545
- Mageia 6 Mass Rebuild

* Wed Aug 26 2015 cjw <cjw> 0.9.3-6.mga6
+ Revision: 870013
- rebuild with gcc 5

* Wed Oct 15 2014 umeabot <umeabot> 0.9.3-5.mga5
+ Revision: 748008
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.9.3-4.mga5
+ Revision: 687702
- Mageia 5 Mass Rebuild

* Sun Sep 14 2014 wally <wally> 0.9.3-3.mga5
+ Revision: 675259
- fix lib pkg name
- drop old and unneeded obsoletes

* Sat Sep 06 2014 diogenese <diogenese> 0.9.3-2.mga5
+ Revision: 672902
- Updated source to 0.9.3
- Patched Encrypt test for i586 build
+ luigiwalser <luigiwalser>
- 0.9.3
- remove upstreamed patches

* Sun Jul 06 2014 fwang <fwang> 0.9.2-3.mga5
+ Revision: 644177
- build with recent freetype
+ tv <tv>
- patch 0: fix build with lua-5.2 (from FC)
- rebuild with lua-5.2

* Sat Oct 19 2013 umeabot <umeabot> 0.9.2-2.mga4
+ Revision: 528172
- Mageia 4 Mass Rebuild

* Sun Jun 16 2013 sander85 <sander85> 0.9.2-1.mga4
+ Revision: 443640
- New version: 0.9.2

* Sun Jan 13 2013 umeabot <umeabot> 0.9.1-3.mga3
+ Revision: 378003
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Jan 13 2013 fwang <fwang> 0.9.1-2.mga3
+ Revision: 367781
- fix build with gcc 4.7

* Fri Dec 23 2011 fwang <fwang> 0.9.1-2.mga2
+ Revision: 186418
- rebuild for new libtiff

* Wed Sep 28 2011 supp <supp> 0.9.1-1.mga2
+ Revision: 150008
- update to 0.9.1

* Sun Mar 27 2011 blino <blino> 0.8.4-1.mga1
+ Revision: 78045
- imported package podofo


* Tue Oct 26 2010 Ahmad Samir <ahmadsamir@mandriva.org> 0.8.4-1mdv2011.0
+ Revision: 589450
- update to 0.8.4

* Wed Aug 25 2010 Funda Wang <fwang@mandriva.org> 0.8.2-1mdv2011.0
+ Revision: 573150
- new version 0.8.2

* Fri Jul 30 2010 Ahmad Samir <ahmadsamir@mandriva.org> 0.8.1-3mdv2011.0
+ Revision: 563233
- add patch from upstream SVN to fix compilation
- update to 0.8.1

* Fri May 28 2010 Juan Luis Baptiste <juancho@mandriva.org> 0.8.0-1mdv2011.0
+ Revision: 546552
- Updated to 0.8.0 and removed patch to fix fprint strings.

* Tue Apr 20 2010 Tomas Kindl <supp@mandriva.org> 0.7.0-2mdv2010.1
+ Revision: 537257
- fix really really bad libname/develname and obsolete it...

* Mon Apr 19 2010 Tomas Kindl <supp@mandriva.org> 0.7.0-1mdv2010.1
+ Revision: 536544
- initial PoDoFo import
- create podofo

